# tables_io

Input/output and conversion interfaces for tabular data formats.


## People

* [Eric Charles](https://github.com/LSSTDESC/qp/issues/new?body=@eacharles) (SLAC)


## License, Contributing etc

The code in this repo is available for re-use under the MIT license.
